#
# spec file for package python-QDarkStyle
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define         X_display         ":98"
Name:           python-QDarkStyle%{psuffix}
Version:        2.8.1
Release:        lp152.1.1
Summary:        A dark stylesheet for Python and Qt applications
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ColinDuquesnoy/QDarkStyleSheet
Source:         https://github.com/ColinDuquesnoy/QDarkStyleSheet/archive/v%{version}.tar.gz#/QDarkStyle-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-QtPy >= 1.9
Requires:       python-helpdev >= 0.6.10
Requires:       python-setuptools
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module QDarkStyle = %{version}}
BuildRequires:  %{python_module QtPy >= 1.9}
BuildRequires:  %{python_module helpdev >= 0.6.10}
BuildRequires:  %{python_module pyside2}
BuildRequires:  %{python_module pytest-qt}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  xvfb-run
%endif
%python_subpackages

%description
QDarkStyle is a dark stylesheet for Python and Qt applications.

%prep
%setup -q -n QDarkStyleSheet-%{version}
sed -i '1{\,^#!%{_bindir}/env python,d}' qdarkstyle/*.py qdarkstyle/utils/*.py

%build
%if !%{with test}
%python_build
%endif

%if %{with test}
%check
export LANG=C.UTF-8
export PYTHONDONTWRITEBYTECODE=1

%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} xvfb-run $python example/example.py --qt_from=pyqt5 --test
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} xvfb-run $python example/example.py --qt_from=pyqt5 --test --no_dark
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} xvfb-run $python example/example.py --qt_from=pyside2 --test
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} xvfb-run $python example/example.py --qt_from=pyside2 --test --no_dark
%endif

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if !%{with test}
%files %{python_files}
%doc AUTHORS.rst CHANGES.rst README.rst
%license LICENSE.rst
%{_bindir}/qdarkstyle
%{python_sitelib}/qdarkstyle
%{python_sitelib}/QDarkStyle-*.egg-info
%endif

%changelog
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Add _multibuild to run the test in a flavor and use xvfb-run
  instead of calling the Xvfb server directly and depending on the
  xorg-x11-server-Xvfb package which is not available in SLE/Leap.
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 2.8.1:
  * Fix rst file formats and links #229
  * Add .gitattributes for generated and documentation files
  * Add more complete tox and Travis envs with many checks
  * Fix removing message format argument
  * Fix QGroupBox small indicator size #218
  * Fix QGroupBox incorrect indicator icon when unfocused #219
  * Fix QDateTimeEdit incorrect drop-down arrow icon #220
  * Fix documentation
* Tue Jan 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the tarball fetching
* Sat Jan 25 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- disable python2 as build dependency pyside is only available on python3
- update to version 2.8:
  - Fix tooltip giant rectangle #174
  - Fix QTextEdit wihout borders inside frame #188
  - Fix PyQt5 issuies on dropbown #191
  - Fix combo box with icons #169
  - Fix QToolbBar vertical handle #210
  - Fix pane tab labelcropped on activation #199
  - Enhance vertical/horiontal lines #184
  - Enhance tool button size and spacing #181, #183, #202
  - Enhance buttons and inputs with focus, blue border #194, #211
  - Enhance QSplitter #207
  - Removed QStatusBar vertical lines #205
- update to version 2.7:
  - Remove utils from import in qdarkstyle, #170
  - Fix border colors in tool button #176
  - Fix scroll area and stacked with 2px padding, #159
  - Fix backgroung submenu color, #179
  - Fix extra border aside header's arrow indicator, #180
  - Fix menu right arrrow indicator
  - Fix slide bars colors, #150
  - Fix QLabels problems, #163, #139
  - Fix problems with example settings using PySide2 and --no\_dark #167
  - Provide SVG files for all images, standard names and sizes, fix images, #149
  - Improve images and add high resolution images, #140
  - Improve docs
  - Add check to scripts for generating images, #137
  - Fix tox and travis scripts #76
  - Provide docs in RTD, part of #160
  - Add helpdev depedency for reports and checks, #147
  - Update authors and maintainers
* Thu May 23 2019 pgajdos@suse.com
- version update to 2.6.8
  - Fix double border in QtabWidget for pyqt5
  - Fix widgets border in QTabWidget as QLabel  #141, #123, #126
  - Fix QTab scroller buttons background #136
  - Update color from images, fix #127
  - Add retina resolution @2x, fix #140
  - Intermediate version before merge PR #142 adding scripts
  - Fix combobox indicator and padding #132
  - Fix PyQtGraph plot axes covered by padding #134
  - Update authors
  - Fix tabbed bordeless frames and add more examples, #123, #126
  - Add feedback to pressed buttons, #133
  - Change future warning to pending deprecation for developers, #125 in v2.x
  - Fix hover in qtabwidget, #128
* Tue Jan 29 2019 Antonio Larrosa <alarrosa@suse.com>
- Use version from git and enable tests (just for python3 since
  pyside2 is not available for python2 and just qt5 bindings
  because qt4 doesn't support painting offscreen and thus needs
  an X server).
* Sun Jan 27 2019 alarrosa@suse.com
- Initial release of python-QDarkStyle 2.6.5
